==> openGion6.6.0.1_core.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE38S.sql <==
/****************************************************************************/
/* GE38 ( ﾌｧｲﾙ種別ﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2016/10/27 10:57:15                                            */
/****************************************************************************/

CREATE TABLE GE38 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , SYFILE       varchar           (  100 )                  NOT NULL            /*  20 ﾌｧｲﾙ種別     */
 , SYNAME       varchar           (  200 )                                      /*  30 種別名称     */
 , DESCRIPTION  varchar           ( 4000 )                                      /*  40 概要説明     */
 , HINAGATA     varchar           (  300 )                                      /*  50 雛形ﾌｧｲﾙ     */
 , SAVE_FOLDER  varchar           (  300 )                                      /*  60 保管ﾌｫﾙﾀﾞ    */
 , FILE_URL     varchar           (  300 )                                      /*  70 ﾌｧｲﾙURL      */
 , ICON_URL     varchar           (  300 )                                      /*  80 ｱｲｺﾝURL      */
 , ROLES        varchar           (  500 )                                      /*  90 ﾛｰﾙｽﾞ        */
 , SU_LMT       INTEGER                         DEFAULT 0   NOT NULL            /* 100 閲覧制限数   */
 , DY_LMT       INTEGER                         DEFAULT 0   NOT NULL            /* 110 閲覧期日     */
 , SIZE_LMT     INTEGER                         DEFAULT 0   NOT NULL            /* 120 ｻｲｽﾞ制限     */
 , SUFFIX_LMT   varchar           (  200 )                                      /* 130 拡張子制限   */
 , FGANGO       varchar           (    1 )      DEFAULT 0   NOT NULL            /* 140 暗号化FG     */
 , FGZIP        varchar           (    1 )      DEFAULT 0   NOT NULL            /* 150 圧縮FG       */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成社員     */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);

==> openGion6.8.2.0_core.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE38S.sql <==
/****************************************************************************/
/* GE38 ( ﾌｧｲﾙ種別ﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2017/07/18 08:42:12                                            */
/****************************************************************************/

CREATE TABLE GE38 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , SYFILE       varchar           (  100 )                  NOT NULL            /*  20 ﾌｧｲﾙ種別     */
 , SYNAME       varchar           (  200 )                                      /*  30 種別名称     */
 , DESCRIPTION  varchar           ( 4000 )                                      /*  40 概要説明     */
 , HINAGATA     varchar           (  300 )                                      /*  50 雛形ﾌｧｲﾙ     */
 , SAVE_FOLDER  varchar           (  300 )                                      /*  60 保管ﾌｫﾙﾀﾞ    */
 , FILE_URL     varchar           (  300 )                                      /*  70 ﾌｧｲﾙURL      */
 , ICON_URL     varchar           (  300 )                                      /*  80 ｱｲｺﾝURL      */
 , ROLES        varchar           ( 2000 )                                      /*  90 ﾛｰﾙｽﾞ        */
 , SU_LMT       INTEGER                         DEFAULT 0   NOT NULL            /* 100 閲覧制限数   */
 , DY_LMT       INTEGER                         DEFAULT 0   NOT NULL            /* 110 閲覧期日     */
 , SIZE_LMT     INTEGER                         DEFAULT 0   NOT NULL            /* 120 ｻｲｽﾞ制限     */
 , SUFFIX_LMT   varchar           (  200 )                                      /* 130 拡張子制限   */
 , FGANGO       varchar           (    1 )      DEFAULT '0' NOT NULL            /* 140 暗号化FG     */
 , FGZIP        varchar           (    1 )      DEFAULT '0' NOT NULL            /* 150 圧縮FG       */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成社員     */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);
